<template>
  <j-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭">

    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :model="model" :rules="validatorRules">
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="code" label="单据号">
          <a-input placeholder="编码系统自动生成" v-model="model.code" disabled />
        </a-form-model-item>
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="equipmentId" label="设备编号">
          <lx-search-equipment-select placeholder="请输入设备编号或名称搜索"
                                      v-model="model.equipmentId"></lx-search-equipment-select>
        </a-form-model-item>

        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="leanDepartId" label="借入车间">
          <a-tree-select v-model="model.leanDepartId"
                         style="width: 100%"
                         :tree-data="treeData"
                         :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }"
                         placeholder="请选择借入车间"
                         allow-clear
                         tree-default-expand-all
          >
          </a-tree-select>
        </a-form-model-item>
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="leanReason" label="借用原因">
          <a-textarea placeholder="请输入借用原因" v-model="model.leanReason" />
        </a-form-model-item>
        <a-form-model-item :labelCol="labelCol" :wrapperCol="wrapperCol" prop="remark" label="备注">
          <a-textarea placeholder="请输入备注" v-model="model.remark" />
        </a-form-model-item>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>

<script>
import { getAction, httpAction } from '@/api/manage'
  import moment from "moment"
  import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'

  export default {
    name: "EamEquipmentLeanOutModal",
    components: { LxSearchEquipmentSelect },
    data () {
      return {
        title:"操作",
        visible: false,
        model: {},
        editable: false,
        labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
        },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
        },
        confirmLoading: false,
        treeData: [],
        validatorRules:{
          equipmentId: [
            { required: true, message: '请选择设备！' }
          ],
          leanDepartId: [
            { required: true, message: '请选择车间！' }
          ],
          leanReason: [
            { required: true, message: '请输入借用原因！' }
          ],
        },
        url: {
          add: "/eam/eamEquipmentLeanOut/add",
          edit: "/eam/eamEquipmentLeanOut/edit",
          loadProductionOptions:'/mdc/mdcProduction/loadProductionTreeOptions',
        },
      }
    },
    created () {
      this.loadAllProductionTree();
    },
    methods: {
      add () {
        //初始化默认值
        //初始化默认值
        this.model = {}
        this.visible = true
        this.editable = false
      },
      edit (record) {
        this.model = Object.assign({}, record)
        this.visible = true
        this.editable = true
        this.loadDetail(record.id)
      },
      close () {
        this.$emit('close');
        this.visible = false;
        this.$refs.form.clearValidate();
      },
      handleOk () {
        const that = this;
        // 触发表单验证
         this.$refs.form.validate(valid => {
          if (valid) {
            that.confirmLoading = true;
            let httpurl = '';
            let method = '';
            if(!this.model.id){
              httpurl+=this.url.add;
              method = 'post';
            }else{
              httpurl+=this.url.edit;
               method = 'put';
            }
            httpAction(httpurl,this.model,method).then((res)=>{
              if(res.success){
                that.$message.success(res.message);
                that.$emit('ok');
                that.close();
              }else{
                that.$message.warning(res.message);
              }
            }).finally(() => {
              that.confirmLoading = false;
            })
          }else{
             return false;
          }
        })
      },
      handleCancel () {
        this.close()
      },
      loadAllProductionTree() {
        //加载车间选择树
        getAction(this.url.loadProductionOptions).then(res => {
          if (res.success) {
            this.treeData = [...res.result]
          }else {
            that.$message.warning(res.message)
          }
        })
      },

    }
  }
</script>

<style lang="less" scoped>

</style>